@@ -5,6 +5,7 @@
 #
 
 import abc
+import asyncio
 import contextlib
 import subprocess
 import time as _time
@@ -147,6 +148,7 @@ class InfoWatcher:
         self._last_status_check = float("-inf")
 
 
+# pylint: disable=too-many-public-methods
 class Job(tp.Generic[R]):
     """Access to a cluster job information and result.
 
@@ -309,7 +311,10 @@ class Job(tp.Generic[R]):
 
         if self._sub_jobs:
             all_exceptions = [sub_job.exception() for sub_job in self._sub_jobs]
-            exceptions = [e for e in all_exceptions if e is not None]
+            # unexpected pylint issue on correct code:
+            exceptions = [
+                e for e in all_exceptions if e is not None  # pylint: disable=used-before-assignment
+            ]
             if not exceptions:
                 return None
             return exceptions[0]
@@ -409,7 +414,7 @@ class Job(tp.Generic[R]):
 
         Note
         ----
-        This function is not full proof, and may say that the job is not terminated even
+        This function is not foolproof, and may say that the job is not terminated even
         if it is when the job failed (no result file, but job not running) because
         we avoid calling sacct/cinfo everytime done is called
         """
@@ -485,6 +490,12 @@ class Job(tp.Generic[R]):
             return "\n".join(stderr_not_none)
         return self._get_logs_string("stderr")
 
+    def awaitable(self) -> "AsyncJobProxy[R]":
+        """Returns a proxy object that provides asyncio methods
+        for this Job.
+        """
+        return AsyncJobProxy(self)
+
     def __repr__(self) -> str:
         state = "UNKNOWN"
         try:
@@ -507,6 +518,64 @@ class Job(tp.Generic[R]):
         self._register_in_watcher()
 
 
+class AsyncJobProxy(tp.Generic[R]):
+    def __init__(self, job: Job[R]):
+        self.job = job
+
+    async def wait(self, poll_interval: tp.Union[int, float] = 1) -> None:
+        """same as wait() but with asyncio sleep."""
+        while not self.job.done():
+            await asyncio.sleep(poll_interval)
+
+    async def result(self, poll_interval: tp.Union[int, float] = 1) -> R:
+        """asyncio version of the result() method.
+        Wait asynchornously for the result to be available by polling the self.done() method.
+        Parameters
+        ----------
+        poll_interval: int or float
+            how often to check if the result is available, in seconds
+        """
+        await self.wait(poll_interval)
+        return self.job.result()
+
+    async def results(self, poll_interval: tp.Union[int, float] = 1) -> tp.List[R]:
+        """asyncio version of the results() method.
+
+        Waits asynchornously for ALL the results to be available by polling the self.done() method.
+
+        Parameters
+        ----------
+        poll_interval: int or float
+            how often to check if the result is available, in seconds
+        """
+        await self.wait(poll_interval)
+        # results are ready now
+        return self.job.results()
+
+    def results_as_compteled(self, poll_interval: tp.Union[int, float] = 1) -> tp.Iterator[asyncio.Future]:
+        """awaits for all tasks results concurrently. Note that the order of results is not guaranteed to match the order
+        of the tasks anymore as the earliest task coming back might not be the first one you sent.
+
+        Returns
+        -------
+        an iterable of Awaitables that can be awaited on to get the earliest result available of the remaining tasks.
+
+        Parameters
+        ----------
+        poll_interval: int or float
+            how often to check if the result is available, in seconds
+
+        (see https://docs.python.org/3/library/asyncio-task.html#asyncio.as_completed)
+        """
+        if self.job.num_tasks > 1:
+            yield from asyncio.as_completed(
+                [self.job.task(i).awaitable().result(poll_interval) for i in range(self.job.num_tasks)]
+            )
+
+        # there is only one result anyway, let's just use async result
+        yield asyncio.ensure_future(self.result())
+
+
 _MSG = (
     "Interactions with jobs are not allowed within "
     '"with executor.batch()" context (submissions/creations only happens at exit time).'
