@@ -265,7 +265,7 @@ class SlurmExecutor(core.PicklingExecutor):
         params = super()._convert_parameters(params)
         # replace type in some cases
         if "mem" in params:
-            params["mem"] = f"{params['mem']}GB"
+            params["mem"] = _convert_mem(params["mem"])
         return params
 
     def _internal_update_parameters(self, **kwargs: Any) -> None:
@@ -387,10 +387,10 @@ def _make_sbatch_string(
     command: str,
     folder: tp.Union[str, Path],
     job_name: str = "submitit",
-    partition: str = None,
+    partition: tp.Optional[str] = None,
     time: int = 5,
     nodes: int = 1,
-    ntasks_per_node: int = 1,
+    ntasks_per_node: tp.Optional[int] = None,
     cpus_per_task: tp.Optional[int] = None,
     cpus_per_gpu: tp.Optional[int] = None,
     num_gpus: tp.Optional[int] = None,  # legacy
@@ -402,16 +402,17 @@ def _make_sbatch_string(
     mem_per_gpu: tp.Optional[str] = None,
     mem_per_cpu: tp.Optional[str] = None,
     signal_delay_s: int = 90,
-    comment: str = "",
-    constraint: str = "",
-    exclude: str = "",
-    gres: str = "",
-    exclusive: tp.Union[bool, str] = False,
+    comment: tp.Optional[str] = None,
+    constraint: tp.Optional[str] = None,
+    exclude: tp.Optional[str] = None,
+    gres: tp.Optional[str] = None,
+    exclusive: tp.Optional[tp.Union[bool, str]] = None,
     array_parallelism: int = 256,
     wckey: str = "submitit",
     stderr_to_stdout: bool = False,
     map_count: tp.Optional[int] = None,  # used internally
     additional_parameters: tp.Optional[tp.Dict[str, tp.Any]] = None,
+    srun_args: tp.Optional[tp.Iterable[str]] = None,
 ) -> str:
     """Creates the content of an sbatch file with provided parameters
 
@@ -427,13 +428,15 @@ def _make_sbatch_string(
     signal_delay_s: int
         delay between the kill signal and the actual kill of the slurm job.
     setup: list
-        a list of command to run in sbatch befure running srun
+        a list of command to run in sbatch before running srun
     map_size: int
         number of simultaneous map/array jobs allowed
     additional_parameters: dict
         Forces any parameter to a given value in sbatch. This can be useful
         to add parameters which are not currently available in submitit.
         Eg: {"mail-user": "blublu@fb.com", "mail-type": "BEGIN"}
+    srun_args: List[str]
+        Add each argument in the list to the srun call
 
     Raises
     ------
@@ -451,8 +454,9 @@ def _make_sbatch_string(
         "setup",
         "signal_delay_s",
         "stderr_to_stdout",
+        "srun_args",
     ]
-    parameters = {k: v for k, v in locals().items() if v and v is not None and k not in nonslurm}
+    parameters = {k: v for k, v in locals().items() if v is not None and k not in nonslurm}
     # rename and reformat parameters
     parameters["signal"] = f"USR1@{signal_delay_s}"
     if job_name:
@@ -494,10 +498,20 @@ def _make_sbatch_string(
     # commandline (this will run the function and args specified in the file provided as argument)
     # We pass --output and --error here, because the SBATCH command doesn't work as expected with a filename pattern
     stderr_flag = "" if stderr_to_stdout else f"--error {stderr}"
+    if srun_args is None:
+        srun_command = "srun"
+    else:
+        srun_command = f"srun {' '.join(srun_args)}"
     lines += [
         "",
         "# command",
         "export SUBMITIT_EXECUTOR=slurm",
-        f"srun --output {stdout} {stderr_flag} --unbuffered {command}\n",
+        f"{srun_command} --output {stdout} {stderr_flag} --unbuffered {command}\n",
     ]
     return "\n".join(lines)
+
+
+def _convert_mem(mem_gb: float) -> str:
+    if mem_gb == int(mem_gb):
+        return f"{int(mem_gb)}GB"
+    return f"{int(mem_gb * 1024)}MB"
